OiRA

Help

1. Priprema
2. Uključite
3. Prepoznavanje + procjena
4. Plan mjera
   1. 1.1.1 Slips, trips and falls are not prevented.
   2. 1.1.2 Collisions, bumps, and jamming are not prevented.
   3. 1.1.4 Exposure to noise is neither prevented nor controlled.
   4. 1.1.6 Exposure to biological substances is neither prevented nor controlled
   5. Ω.1 The entrance floor is often wet
   6. Title of the first custom risk
   7. This is another custom risk added by the user
   - Postoji rizik
5. Završni dokumenti
6. Status 9%

# Commercial guarding, Leicester

Nakon što ste identificirali rizike, trebate izraditi plan mjera za upravljanje rizicima. Kako biste eliminirali i smanjili rizike, potrebno je da odredite preventivne i zaštitne mjere koje treba poduzeti.

Među stvarima koje treba uzeti u obzir za ovaj korak su:

1. Može li se rizik izbjeći? Može li se u cijelosti ukloniti? To se primjerice može postići s pomoću:
   - razmotriti je li zadatak ili posao nužan
   - uklanjanje opasnosti
2. Ako neke rizike nije moguće izbjeći, kako se mogu smanjiti na razinu koja ne ugrožava zdravlje i sigurnost izloženih osoba?

Čim odlučite kako eliminirati ili smanjiti neki određeni rizik, odmah opišite konkretnu(e) aktivnost(i) potrebnu(e) da bi se to postiglo. Osim toga unesite i detalje o razini stručnosti i/ili ostalim potrebnim zahtjevima kako bi te aktivnosti bile učinkovite.

Kreiraj plan mjera

Scroll to top
Back

## action-plan-landing.html

Više

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More